import { Component, OnInit, ViewChild, AfterViewInit } from "@angular/core";
import { Location } from '@angular/common';
import { NzFormatEmitEvent, NzTreeNodeOptions, NzTreeComponent, NzMessageService } from 'ng-zorro-antd';
import { ToolService } from 'src/app/services/tool.service';
import { MainService } from 'src/app/services/main.service';
import cloneDeep from 'lodash-es/cloneDeep'
import { OverlayScrollbarsComponent } from 'overlayscrollbars-ngx';
import { Router, ActivatedRoute } from '@angular/router';
import { Subject } from 'rxjs';
import { debounceTime } from 'rxjs/operators';
import { FormGroup, FormBuilder, Validators, FormControl } from '@angular/forms';
import { v4 as uuidv4, validate as uuidValidate } from 'uuid';

@Component({
  selector: "app-configuration-center",
  templateUrl: "./configuration-center.component.html",
  styleUrls: ["./configuration-center.component.less"],
})
export class ConfigurationCenterComponent implements OnInit, AfterViewInit {
  constructor(
    private tool: ToolService,
    private mainService: MainService,
    private message: NzMessageService,
    private router: Router,
    private route: ActivatedRoute,
    private _location: Location,
    private fb: FormBuilder,
  ){}
  @ViewChild('nzTreeComponent', { static: false }) nzTreeComponent: NzTreeComponent;
  @ViewChild('nzTreeComponentCopy', { static: false }) nzTreeComponentCopy: NzTreeComponent;
  @ViewChild("osComponentRef1", {
    read: OverlayScrollbarsComponent,
    static: false,
  })
  osComponentRef1: OverlayScrollbarsComponent;
  @ViewChild("osComponentRef2", {
    read: OverlayScrollbarsComponent,
    static: false,
  })
  osComponentRef2: OverlayScrollbarsComponent;
  @ViewChild("osComponentRef3", {
    read: OverlayScrollbarsComponent,
    static: false,
  })
  osComponentRef3: OverlayScrollbarsComponent;
  defaultCheckedKeys = [];
  defaultSelectedKeys = [];
  defaultExpandedKeys = [];
  nodes: NzTreeNodeOptions[] = [];
  currentHospital; //当前院区
  maskFlag: any = false;
  isLoading = false;

  // tab
  tagList:any = [
    { id: 1, name: '故障现象',},
    { id: 2, name: '优先级',},
    { id: 3, name: '数据字典',},
  ];
  // 部门设置、全院设置
  hospitalConfig:any = 2;
  hospitalConfigList:any = [
    // { id: 1, name: '部门设置',},
    { id: 2, name: '全院设置',},
  ];

  changeInpSubject = new Subject(); //防抖
  debounceSubject = new Subject(); //防抖

  ngOnInit(): void {
    //防抖
    this.changeInpSubject.pipe(debounceTime(500)).subscribe((v) => {
      if(v[0] === 'user'){
        this.getUsers(v[1]);
      } else if(v[0] === 'group'){
        this.getGroups(v[1]);
      }
    });

    this.debounceSubject.pipe(debounceTime(500)).subscribe((v) => {
      if(v[0]){
        this.getCategoryList(v[0], v[1].id);
      }
      this.getCategoryConfigList(v[1].id);
    });

    this.currentHospital = this.tool.getCurrentHospital();
  }

  ngAfterViewInit(){
    this.clickTag(this.tagList[0]);
  }

  // 点击tab
  activeTagId:any = 1;
  clickTag(tag){
    this.activeTagId = tag.id;
    if(this.activeTagId === 1){
      // 故障现象
      setTimeout(() => {
        this.tableCategoryHeight = document.querySelector('#categoryTable').clientHeight - 8 - document.querySelector('#categoryTable .thead').clientHeight;
      }, 0)
      if(this.currentHospital.type && this.currentHospital.type.value === '6'){
        // 是责任部门
        let flag = this.hospitalConfigList.some(v => v.id === 1);
        !flag && this.hospitalConfigList.unshift({ id: 1, name: '部门设置',});
      }
      this.getCategoryList(1);
      this.getHospitals(1);
      this.getPrioritys();
      this.getScores();
    } else if(this.activeTagId === 2){
      // 优先级
      setTimeout(() => {
        this.tablePriorityHeight = document.querySelector('#priorityTable').clientHeight - document.querySelector('#priorityTable .list-template__top').clientHeight - 8 - document.querySelector('#priorityTable .thead').clientHeight;
      }, 0)
      this.getPriorityList();
    } else if(this.activeTagId === 3){
      // 数据字典
      this.initDictionaryForm();
      this.getDictionaryList();
    }
  }

  formatterMinute = (value: number) => `${value} 分钟`;
  parserMinute = (value: string) => value.replace(' 分钟', '');

  // 修改院区
  changeHospital(id){
    this.validateConfigForm.controls.dutyId.setValue(null);
    this.validateConfigForm.controls.userId.setValue(null);
    this.validateConfigForm.controls.groupId.setValue(null);

    this.dutyList = [];
    this.userList = [];
    this.groupList = [];
    this.getHospitals(2, id);
  }

  // 修改责任部门
  changeDuty(id){
    this.validateConfigForm.controls.userId.setValue(null);
    this.validateConfigForm.controls.groupId.setValue(null);

    this.userList = [];
    this.groupList = [];
    this.getGroups();
  }

  // 选择部门设置或全院设置
  changeHospitalConfig(e){
    console.log(e);
    this.getCategoryList(1);

    this.categoryList2 = [];
    this.categoryList3 = [];

    this.activeCategory1 = {};
    this.activeCategory2 = {};
    this.activeCategory3 = {};

    this.categoryConfigList = [];
  }

  // 获取优先级列表
  priorityList: any[] = []; //表格数据
  tablePriorityHeight:number = 0;
  getPriorityList() {
    let data = {
      idx: 0,
      sum: 9999,
      priority: {},
    };
    this.loading1 = true;
    this.mainService
      .getFetchDataList("simple/data", "priority", data)
      .subscribe((data) => {
        this.loading1 = false;
        if (data.status == 200) {
          this.priorityList = data.list || [];
        }else{
          this.message.error(data.msg || "请求数据失败");
        }
      });
  }

  // 新增优先级弹框
  modelName = ""; //模态框名称
  modalPriority: boolean = false; //新增/编辑模态框
  add: boolean; //true:新增；false:编辑
  addPriorityModal() {
    this.modelName = "新增";
    this.add = true; //新增
    this.modalPriority = true;
    this.initPriorityForm();
  }
  //关闭新增/编辑弹框
  hidePriorityModal() {
    this.modalPriority = false;
  }

  // 初始化新增form表单
  validatePriorityForm: FormGroup; //新增/编辑表单
  initPriorityForm() {
    this.validatePriorityForm = this.fb.group({
      name: [null, [Validators.required]],//优先级名称
      orders: [null, [Validators.required]],//排序号
      responseTime: [0, [Validators.required]],//响应时间
      handleTime: [0, [Validators.required]],//解决时间
    });
    console.log(this.validatePriorityForm.controls)
  }

  // 编辑
  coopData: any = {}; //当前操作列
  editPriority(data) {
    console.log(data);
    this.modelName = "编辑";
    this.add = false;
    this.modalPriority = true;
    this.initPriorityForm();
    this.coopData = data;
    this.validatePriorityForm.controls.name.setValue(data.name);
    this.validatePriorityForm.controls.orders.setValue(data.orders);
    this.validatePriorityForm.controls.responseTime.setValue(data.responseTime);
    this.validatePriorityForm.controls.handleTime.setValue(data.handleTime);
  }

  // 新增/编辑表单提交
  btnLoading: boolean = false; //提交按钮loading状态
  submitPriorityForm(): void {
    for (const i in this.validatePriorityForm.controls) {
      this.validatePriorityForm.controls[i].markAsDirty();
      this.validatePriorityForm.controls[i].updateValueAndValidity();
    }
    if (this.validatePriorityForm.invalid) {
      return;
    }
    console.log(this.validatePriorityForm.value);
    this.btnLoading = true;
    let postData:any = {};

    if (this.add) {
      //增加
      postData = {
        // priority: {
          name: this.validatePriorityForm.value.name,
          orders: this.validatePriorityForm.value.orders,
          responseTime: this.validatePriorityForm.value.responseTime,
          handleTime: this.validatePriorityForm.value.handleTime,
        // }
      };
    } else {
      //编辑
      postData = {
        // priority: {
          ...this.coopData,
          ...{
            name: this.validatePriorityForm.value.name,
            orders: this.validatePriorityForm.value.orders,
            responseTime: this.validatePriorityForm.value.responseTime,
            handleTime: this.validatePriorityForm.value.handleTime,
          }
        // }
      };
    }
    this.mainService
      .simplePost("addData", "priority", postData)
      .subscribe((result) => {
        this.btnLoading = false;
        this.hidePriorityModal();
        let msg = "";
        if (this.add) {
          msg = "新增";
        } else {
          msg = "修改";
        }
        if (result.status == 200) {
          this.showPromptModal(msg, true, '');
        } else {
          this.showPromptModal(msg, false, result.msg);
        }
      });
  }

  // 新增故障现象弹框
  modalCategory: boolean = false; //新增/编辑模态框
  coopType: number = 0;
  addCategoryModal(type:number) {
    this.coopType = type;
    this.modelName = "新增";
    this.add = true; //新增
    this.modalCategory = true;
    this.initCategoryForm();
  }
  //关闭新增/编辑弹框
  hideCategoryModal() {
    this.modalCategory = false;
  }

  // 初始化新增form表单
  validateCategoryForm: FormGroup; //新增/编辑表单
  initCategoryForm() {
    this.validateCategoryForm = this.fb.group({
      name: [null, [Validators.required]],//名称
    });
    console.log(this.validateCategoryForm.controls)
  }

  // 编辑
  // editCategory(data) {
  //   console.log(data);
  //   this.modelName = "编辑";
  //   this.add = false;
  //   this.modalCategory = true;
  //   this.initCategoryForm();
  //   this.coopData = data;
  //   this.validateCategoryForm.controls.name.setValue(data.name);
  // }

  // 新增/编辑表单提交
  submitCategoryForm(): void {
    for (const i in this.validateCategoryForm.controls) {
      this.validateCategoryForm.controls[i].markAsDirty();
      this.validateCategoryForm.controls[i].updateValueAndValidity();
    }
    if (this.validateCategoryForm.invalid) {
      return;
    }
    console.log(this.validateCategoryForm.value);
    this.btnLoading = true;
    // -----------------------------------
    let postData:any = {
      category: {
        hosId: this.currentHospital.id,
        parent: this.coopType === 1 ? undefined : this['activeCategory' + (this.coopType - 1)],
        category: this.validateCategoryForm.value.name,
        hierarchy: this.coopType,
        dutyIds: this.hospitalConfig === 1 ? this.currentHospital.id.toString() : undefined,
      },
    };
    this.mainService
      .incidentPost("checkIncidentCategory", postData)
      .subscribe((result) => {
        let msg = "";
        if (this.add) {
          msg = "新增";
        } else {
          msg = "修改";
        }
        if (result.status == 200) {
          this.submitCategoryAddForm();
        } else if(result.status == 502) {
          this.btnLoading = false;
          this.showDelModal(null, result.msg, '', 'relevance');
        } else {
          this.btnLoading = false;
          this.showPromptModal(msg, false, result.msg);
        }
      });
    // -----------------------------------
  }

  submitCategoryAddForm(): void {
    let postData:any = {};
    if (this.add) {
      //增加
      console.log(this['activeCategory' + this.coopType])
      postData = {
        category: {
          hosId: this.currentHospital.id,
          parent: this.coopType === 1 ? undefined : this['activeCategory' + (this.coopType - 1)],
          category: this.validateCategoryForm.value.name,
          hierarchy: this.coopType,
          dutyIds: this.hospitalConfig === 1 ? this.currentHospital.id.toString() : undefined,
        },
      };
    } else {
      //编辑
      // postData = {
      //   category: {
      //     hosId: this.currentHospital.id,
      //     parent: this.coopType === 1 ? undefined : { id: this.coopData.id },
      //     category: this.validateCategoryForm.value.name,
      //     hierarchy: this.coopType,
      //   },
      // };
    }
    this.mainService
      .incidentPost("addIncidentCategory", postData)
      .subscribe((result) => {
        this.btnLoading = false;
        this.hideCategoryModal();
        let msg = "";
        if (this.add) {
          msg = "新增";
        } else {
          msg = "修改";
        }
        if (result.status == 200) {
          this.showPromptModal(msg, true, '');
        } else {
          this.showPromptModal(msg, false, result.msg);
        }
      });
  }

  // ------------------------------
  // 新增故障现象-关联弹框
  modalConfig: boolean = false; //新增/编辑模态框
  addConfigModal() {
    this.modelName = "新增";
    this.add = true; //新增
    this.modalConfig = true;
    this.initConfigForm();
    this.requiredConfigChange('userId', true);
  }
  //关闭新增/编辑弹框
  hideConfigModal() {
    this.modalConfig = false;
  }

  // 初始化新增form表单
  validateConfigForm: FormGroup; //新增/编辑表单
  initConfigForm() {
    this.validateConfigForm = this.fb.group({
      hosId: [null, [Validators.required]],//院区
      dutyId: [null, [Validators.required]],//责任部门
      priority: [null, [Validators.required]],//优先级
      score: [null, [Validators.required]],//积分
      userGroup: [1, [Validators.required]],//分配方式
      userId: [null],//维修人
      groupId: [null, [Validators.required]],//维修组
    });
    console.log(this.validateConfigForm.controls)
  }

  // 选择人|组
  changeUserGroup(id){
    this.validateConfigForm.controls.userId.setValue(null);
    this.validateConfigForm.controls.groupId.setValue(null);
    this.userList = [];
    if(id === 1){
      // 人
      this.requiredConfigChange('userId', true);
    }else if(id === 2){
      // 组
      this.requiredConfigChange('userId', false);
    }
  }

  requiredConfigChange(name: string, required: boolean): void {
    if (!required) {
      this.validateConfigForm.get(name)!.clearValidators();
      this.validateConfigForm.get(name)!.markAsPristine();
    } else {
      this.validateConfigForm.get(name)!.setValidators(Validators.required);
      this.validateConfigForm.get(name)!.markAsDirty();
    }
    this.validateConfigForm.get(name)!.updateValueAndValidity();
  }

  // 编辑
  editConfig(data) {
    console.log(data);
    this.modelName = "编辑";
    this.add = false;
    this.modalConfig = true;
    this.initConfigForm();
    this.coopData = data;
    this.validateConfigForm.controls.hosId.setValue(data.hosId);
    this.validateConfigForm.controls.dutyId.setValue(data.dutyId);
    this.validateConfigForm.controls.priority.setValue(data.priority);
    this.validateConfigForm.controls.score.setValue(data.score ? data.score.id : null);
    this.validateConfigForm.controls.userGroup.setValue(data.userGroup);
    this.validateConfigForm.controls.userId.setValue(data.userId);
    this.validateConfigForm.controls.groupId.setValue(data.groupId);
    if(data.userGroup === 1){
      this.requiredConfigChange('userId', true);
    }else if(data.userGroup === 2){
      this.requiredConfigChange('userId', false);
    }
    data.hosId && this.getHospitals(2, data.hosId);
    data.dutyId && this.getUsers('', true);
    data.dutyId && this.getGroups('', true);
  }

  // 修改组
  changeGroup(id){
    this.validateConfigForm.controls.userId.setValue(null);
    this.getUsers();
  }

  // 新增/编辑表单提交
  submitConfigForm(): void {
    for (const i in this.validateConfigForm.controls) {
      this.validateConfigForm.controls[i].markAsDirty();
      this.validateConfigForm.controls[i].updateValueAndValidity();
    }
    if (this.validateConfigForm.invalid) {
      return;
    }
    console.log(this.validateConfigForm.value);
    this.btnLoading = true;
    let postData:any = {};

    let categoryId = this.activeCategory3.id || this.activeCategory2.id || this.activeCategory1.id;

    if (this.add) {
      //增加
      postData = {
        incidentCategoryConfig: {
          categoryId,
          priority: this.validateConfigForm.value.priority,
          score: { id: this.validateConfigForm.value.score },
          dutyId: this.validateConfigForm.value.dutyId,
          userGroup: this.validateConfigForm.value.userGroup,
          groupId: this.validateConfigForm.value.groupId || undefined,
          userId: this.validateConfigForm.value.userGroup === 1 ? this.validateConfigForm.value.userId : undefined,
          hosId: this.currentHospital.id,
        }
      };
    } else {
      //编辑
      postData = {
        incidentCategoryConfig: {
          ...this.coopData,
          ...{
            categoryId,
            priority: this.validateConfigForm.value.priority,
            score: { id: this.validateConfigForm.value.score },
            userGroup: this.validateConfigForm.value.userGroup,
            groupId: this.validateConfigForm.value.groupId || undefined,
            userId: this.validateConfigForm.value.userGroup === 1 ? this.validateConfigForm.value.userId : undefined,
          }
        }
      };
    }
    console.log(postData);
    this.mainService
      .coopData("addData", "incidentCategoryConfig", postData)
      .subscribe((result) => {
        this.btnLoading = false;
        this.hideConfigModal();
        let msg = "";
        if (this.add) {
          msg = "新增";
        } else {
          msg = "修改";
        }
        if (result.status == 200) {
          this.showPromptModal(msg, true, '');
        } else {
          this.showPromptModal(msg, false, result.msg);
        }
      });
  }
  // ------------------------------

  // 展示信息提示框（con:提示信息，success:操作是否成功，promptInfo:操作结果提示信息）
  promptContent: string; //操作提示框提示信息
  ifSuccess: boolean; //操作成功/失败
  promptInfo: string; //操作结果提示信息
  promptModalShow: boolean; //操作提示框是否展示
  showPromptModal(con, success, promptInfo?) {
    this.promptModalShow = false;
    this.promptContent = con;
    this.ifSuccess = success;
    this.promptInfo = promptInfo;
    setTimeout(() => {
      this.promptModalShow = true;
    }, 100);
    if(this.activeTagId == 1){
      if(this.coopType !== 0){
        this.getCategoryList(this.coopType, this.coopType === 1 ? undefined : this['activeCategory' + (this.coopType - 1)].id);
      }else{
        this.getCategoryList(this.currentCategoryIndex, this.currentCategoryIndex === 1 ? undefined : this['activeCategory' + (this.currentCategoryIndex - 1)].id);
      }
      if(this.activeCategory3.id || this.activeCategory2.id || this.activeCategory1.id){
        this.getCategoryConfigList(this.activeCategory3.id || this.activeCategory2.id || this.activeCategory1.id);
      }
    } else if(this.activeTagId == 2){
      this.getPriorityList();
    } else if(this.activeTagId == 3){
      this.getDictionaryList();
    }
  }

  delModal: boolean = false; //删除模态框
  tipsMsg1: string; //提示框信息
  tipsMsg2: string; //操作后信息
  confirmDelType: string; //确认的类型（启用/停用，删除）
  showDelModal(
    data,
    tipsMsg1: string,
    tipsMsg2: string,
    type: string,
  ) {
    this.confirmDelType = type;
    this.delModal = true;
    this.coopData = data;
    this.tipsMsg1 = tipsMsg1;
    this.tipsMsg2 = tipsMsg2;
  }
  // 隐藏删除框
  hideDelModal() {
    this.delModal = false;
  }
  // 确认删除
  confirmDel() {
    this.btnLoading = true;
    if (this.confirmDelType === "delPriority") {
      //删除-优先级
      this.mainService
        .simplePost("rmvData", "priority", [this.coopData.id])
        .subscribe((data) => {
          this.btnLoading = false;
          this.delModal = false;
          if (data.status == 200) {
            this.showPromptModal(this.tipsMsg2, true, "");
          } else {
            this.showPromptModal(this.tipsMsg2, false, data.msg);
          }
        });
    } else if (this.confirmDelType === "delDictionary") {
      //删除-数据字典
      this.mainService
        .simplePost("rmvData", "dictionary", [this.coopData.id])
        .subscribe((data) => {
          this.btnLoading = false;
          this.delModal = false;
          if (data.status == 200) {
            this.showPromptModal(this.tipsMsg2, true, "");
          } else {
            this.showPromptModal(this.tipsMsg2, false, data.msg);
          }
        });
    } else if (this.confirmDelType === "relevance") {
      //新增故障现象-关联
      this.btnLoading = false;
      this.delModal = false;
      this.submitCategoryAddForm();
    } else if (this.confirmDelType === "delConfig") {
      //删除-关联
      this.mainService
        .simplePost("rmvData", "incidentCategoryConfig", [this.coopData.id])
        .subscribe((data) => {
          this.btnLoading = false;
          this.delModal = false;
          if (data.status == 200) {
            this.showPromptModal(this.tipsMsg2, true, "");
          } else {
            this.showPromptModal(this.tipsMsg2, false, data.msg);
          }
        });
    } else if (this.confirmDelType === "copy") {
      //向下复制-关联
      let postData:any = {
        type: this.hospitalConfig === 1 ? 'duty': 'hospital',
        category: this.currentCategory,
      };
      postData.category.dutyIds = this.hospitalConfig === 1 ? this.currentHospital.id.toString() : undefined;
      this.mainService
        .incidentPost("copyIncidentCategoryConfig", postData)
        .subscribe((data) => {
          this.btnLoading = false;
          this.delModal = false;
          if (data.status == 200) {
            this.showPromptModal(this.tipsMsg2, true, "");
          } else {
            this.showPromptModal(this.tipsMsg2, false, data.msg);
          }
        });
    }
  }

  // 初始化数据字典新增form表单
  validateDictionaryForm: FormGroup; //新增/编辑表单
  dictionaryList: any = [];
  initDictionaryForm() {
    this.validateDictionaryForm = this.fb.group({
      // name: [null, [Validators.required]],//键
      // value: [null, [Validators.required]],//值
    });
    console.log(this.validateDictionaryForm.controls)
  }

  // 获取数据字典数据
  getDictionaryList() {
    let postData = {
      idx: 0,
      sum: 9999,
      dictionary: {
        key: "incident_category_score"
      }
    }
    this.maskFlag = this.message.loading("正在加载中..", {
      nzDuration: 0,
    }).messageId;
    this.mainService.getFetchDataList('simple/data','dictionary',postData).subscribe(data => {
      this.message.remove(this.maskFlag);
      this.maskFlag = false;
      let list = data.list || [];
      if(list.length){
        this.dictionaryList = list.map(v => {
          return {
            id: v.id,
            name: v.name || null,
            value: v.value || null,
          }
        });
      }else{
        this.dictionaryList = [
          {
            id: uuidv4(),
            name: null,
            value: null,
          }
        ];
      }

      console.log(this.dictionaryList);
      // 动态添加表单
      this.dictionaryList.forEach((obj, i) => {
        for (const key in obj) {
          if(key !== 'id'){
            this.validateDictionaryForm.addControl(key + '_' + obj.id, new FormControl(obj[key], [Validators.required]))
          }
        }
      })
    })
  }

  // 添加数据字典
  addField(i:number): void{
    let obj = {
      id: uuidv4(),
      name: null,
      value: null,
    };

    // 动态添加表单
    for (const key in obj) {
      console.log(key + '_' + obj.id)
      if(key !== 'id'){
        this.validateDictionaryForm.addControl(key + '_' + obj.id, new FormControl(null, [Validators.required]))
      }
    }

    this.dictionaryList.splice(i + 1, 0, obj);
  }

  // 删除
  removeField(obj, i:number): void {
    if(uuidValidate(obj.id)){
      this.dictionaryList.splice(i, 1);
      this.dictionaryList = [...this.dictionaryList];
      // 动态删除表单
      for (const key in obj) {
        this.validateDictionaryForm.removeControl(key + '_' + obj.id);
      }
    }else{
      this.showDelModal(obj,'您确认要删除吗？','删除','delDictionary')
    }
  }

  // 保存数据字典
  saveDictionary(): void {
    console.log(this.coopData)
    for (const i in this.validateDictionaryForm.controls) {
      this.validateDictionaryForm.controls[i].markAsDirty();
      this.validateDictionaryForm.controls[i].updateValueAndValidity();
    }
    if (this.validateDictionaryForm.invalid) {
      return;
    }
    console.log(this.validateDictionaryForm.value);
    let postData:any = {};

    //增加
    postData = [];
    for (let i = 0; i < this.dictionaryList.length; i++) {
      postData.push({
        id: uuidValidate(this.dictionaryList[i].id) ? undefined : this.dictionaryList[i].id,
        name: this.validateDictionaryForm.value['name_' + this.dictionaryList[i].id],
        value: this.validateDictionaryForm.value['value_' + this.dictionaryList[i].id],
        orders: i + 1,
        key: 'incident_category_score',
      })
    }
    console.log(postData);
    this.btnLoading = true;
    this.mainService
      .simplePost("addListData", "dictionary", postData)
      .subscribe((result) => {
        this.btnLoading = false;
        if (result.status == 200) {
          this.showPromptModal('保存', true, '');
        } else {
          this.showPromptModal('保存', false, result.msg || '');
        }
      });
  }

  // 一级故障现象
  loading1:boolean = false;
  tableCategoryHeight:number = 0;
  categoryList1: any[] = [];
  categoryList2: any[] = [];
  categoryList3: any[] = [];
  categoryLoading1:boolean = false;
  categoryLoading2:boolean = false;
  categoryLoading3:boolean = false;
  getCategoryList(type:number, parentId = 0) {
    setTimeout(() => {
      this['categoryLoading' + type] = true;
    }, 0)
    let postData = {
      category: {
        hierarchy: type === 1 ? 1 : undefined,
        dutyIds: this.hospitalConfig === 1 ? this.currentHospital.id.toString()  : undefined,
        parent: type === 1 ? undefined : { id: parentId },
      },
    };
    this.mainService.incidentPost("listIncidentCategory", postData).subscribe(res => {
      this['categoryLoading' + type] = false;
      this['categoryList' + type] = res.data || [];
    })
  }

  // 获取当前选中的故障现象索引
  get currentCategoryIndex(){
    if(this.activeCategory3.id){
      return 3;
    }
    if(this.activeCategory2.id){
      return 2;
    }
    if(this.activeCategory1.id){
      return 1;
    }
  }

  // 获取当前选中的故障现象索引
  get currentCategory(){
    if(this.activeCategory3.id){
      return this.activeCategory3;
    }
    if(this.activeCategory2.id){
      return this.activeCategory2;
    }
    if(this.activeCategory1.id){
      return this.activeCategory1;
    }
  }

  // 获取当前选中的故障现象有没有子故障现象
  get currentChildrenCategoryList(){
    return this.currentCategoryIndex && this.currentCategoryIndex < 3 && this['categoryList' + (this.currentCategoryIndex + 1)].length;
  }
  categoryConfigList:any[] = [];
  getCategoryConfigList(parentId = 0) {
    this.loading1 = true;
    let postData = {
      idx: 0,
      sum: 9999,
      incidentCategoryConfig: {
        categoryId: parentId,
        dutyId: this.hospitalConfig === 1 ? this.currentHospital.id  : undefined,
      },
    };
    this.mainService.getFetchDataList("simple/data", "incidentCategoryConfig", postData).subscribe(res => {
      this.loading1 = false;
      this.categoryConfigList = res.list || [];
    })
  }

  // 数据字典key列表
  dictionaryKeyList: any[] = [
    { id: 1, name: '积分配置',},
  ];

  // 点击数据字典key
  activeDictionaryKey:any = this.dictionaryKeyList[0];
  clickDictionaryKey(item){
    this.activeDictionaryKey = item;
  }

  // 点击故障现象
  activeCategory1:any = {};
  activeCategory2:any = {};
  activeCategory3:any = {};
  clickCategory(item, type:number){
    this.categoryConfigList = [];
    switch(type){
      case 1:
        this.categoryList2 = [];
        this.categoryList3 = [];
        this.activeCategory2 = {};
        this.activeCategory3 = {};
        break;
      case 2:
        this.categoryList3 = [];
        this.activeCategory3 = {};
        break;
    }
    this['activeCategory' + type] = item;
    console.log(this['activeCategory' + type])
    switch(type){
      case 1:
        this.categoryLoading2 = true;
        this.loading1 = true;
        this.debounceSubject.next([2, item]);
        break;
      case 2:
        this.categoryLoading3 = true;
        this.loading1 = true;
        this.debounceSubject.next([3, item]);
        break;
      case 3:
        this.loading1 = true;
        this.debounceSubject.next([0, item]);
        break;
    }
  }

  // 边输边搜节流阀
  changeInp(model, e) {
    this.isLoading = true;
    this.changeInpSubject.next([model, e]);
  }

  // 搜索
  // 获取用户
  userList: any = [];
  getUsers(keyword = '', isShowValue = false) {
    if((!this.validateConfigForm.value.groupId && this.validateConfigForm.value.userGroup === 1) || this.validateConfigForm.value.userGroup === 2){
      this.userList = [];
      return;
    }
    let postData = {
      user: {
        hospital: { id: this.validateConfigForm.value.dutyId },
        name: keyword,
        simpleQuery: true,
        groupdata: { id: this.validateConfigForm.value.groupId },
      },
      idx: 0,
      sum: 10,
    };
    this.mainService
      .getFetchDataList("data", "user", postData)
      .subscribe((data) => {
        this.isLoading = false;
        let userList = data.list || [];
        if(isShowValue && this.coopData && this.coopData.userId){
          userList = userList.filter(v => v.id !== this.coopData.userId)
          userList.unshift(this.coopData.userDTO);
        }
        this.userList = userList;
      });
  }

  // 获取组
  groupList: any = []; //所有所属科室(搜索)
  getGroups(keyword = '', isShowValue = false) {
    if(!this.validateConfigForm.value.dutyId){
      this.groupList = [];
      return;
    }
    let postData = {
      group2: {
        groupName: keyword,
        hospitals: this.validateConfigForm.value.dutyId,
        type: 1,
      },
      idx: 0,
      sum: 10,
    };
    this.mainService
      .getFetchDataList("data", "group2", postData)
      .subscribe((data) => {
        this.isLoading = false;
        let groupList = data.list || [];
        if(isShowValue && this.coopData && this.coopData.groupId){
          groupList = groupList.filter(v => v.id !== this.coopData.groupId)
          groupList.unshift(this.coopData.groupDTO);
        }
        this.groupList = groupList;
      });
  }

  // 获取院区
  hospitalList: any = [];
  dutyList: any = [];
  getHospitals(type:number, parentId?) {
    if(type === 1){
      this.hospitalList = this.tool.getHospitalList().filter(v => !v.parent);
      return;
    }
    if(type === 2 && !parentId){
      this.dutyList = [];
      return;
    }
    let postData = {
      hospital: {
        parent: { id: parentId },
        type: { key: 'hospital_type', value: '6' },
      },
      idx: 0,
      sum: 9999,
    };
    this.mainService
      .getFetchDataList("data", "hospital", postData)
      .subscribe((data) => {
        this.isLoading = false;
        this.dutyList = data.list || [];
      });
  }

  // 获取优先级
  priority_c_List: any = [];
  getPrioritys() {
    let postData = {
      priority: {},
      idx: 0,
      sum: 9999,
    };
    this.mainService
      .getFetchDataList("simple/data", "priority", postData)
      .subscribe((data) => {
        this.isLoading = false;
        this.priority_c_List = data.list || [];
      });
  }

  // 获取积分
  scoreList: any = [];
  getScores() {
    let postData = {
      dictionary: {
        key: "incident_category_score"
      },
      idx: 0,
      sum: 10,
    };
    this.mainService
      .getFetchDataList("simple/data", "dictionary", postData)
      .subscribe((data) => {
        this.isLoading = false;
        this.scoreList = data.list || [];
      });
  }

  // 返回
  goBack(){
    this._location.back();
  }
}
